==> apache-paimon-0.9.0-src.tgz: paimon-0.9.0/paimon-flink/paimon-flink-common/src/main/java/org/apache/paimon/flink/clone/CloneFileInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.flink.clone;

/** The information of copy file. */
public class CloneFileInfo {

    private final String filePathExcludeTableRoot;
    private final String sourceIdentifier;
    private final String targetIdentifier;

    public CloneFileInfo(
            String filePathExcludeTableRoot, String sourceIdentifier, String targetIdentifier) {
        this.filePathExcludeTableRoot = filePathExcludeTableRoot;
        this.sourceIdentifier = sourceIdentifier;
        this.targetIdentifier = targetIdentifier;
    }

    public String getFilePathExcludeTableRoot() {
        return filePathExcludeTableRoot;
    }

    public String getSourceIdentifier() {
        return sourceIdentifier;
    }

    public String getTargetIdentifier() {
        return targetIdentifier;
    }

    @Override
    public String toString() {
        return String.format(
                "{ filePath: %s, sourceIdentifier: %s, targetIdentifier: %s }",
                filePathExcludeTableRoot, sourceIdentifier, targetIdentifier);
    }
}

==> apache-paimon-1.0.0-src.tgz: paimon-1.0.0/paimon-flink/paimon-flink-common/src/main/java/org/apache/paimon/flink/clone/CloneFileInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.flink.clone;

/** The information of copy file. */
public class CloneFileInfo {

    private final String sourceFilePath;
    private final String filePathExcludeTableRoot;
    private final String sourceIdentifier;
    private final String targetIdentifier;

    public CloneFileInfo(
            String sourceFilePath,
            String filePathExcludeTableRoot,
            String sourceIdentifier,
            String targetIdentifier) {
        this.sourceFilePath = sourceFilePath;
        this.filePathExcludeTableRoot = filePathExcludeTableRoot;
        this.sourceIdentifier = sourceIdentifier;
        this.targetIdentifier = targetIdentifier;
    }

    public String getSourceFilePath() {
        return sourceFilePath;
    }

    public String getFilePathExcludeTableRoot() {
        return filePathExcludeTableRoot;
    }

    public String getSourceIdentifier() {
        return sourceIdentifier;
    }

    public String getTargetIdentifier() {
        return targetIdentifier;
    }

    @Override
    public String toString() {
        return String.format(
                "{ sourceFilePath: %s, filePathExcludeTableRoot: %s, sourceIdentifier: %s, targetIdentifier: %s }",
                sourceFilePath, filePathExcludeTableRoot, sourceIdentifier, targetIdentifier);
    }
}
